"use strict";

var _react = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("react"));

var _plasmaCyUtils = /*#__PURE__*/require("@sberdevices/plasma-cy-utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var Cell = /*#__PURE__*/(0, _plasmaCyUtils.getComponent)('Cell');
var CellIcon = /*#__PURE__*/(0, _plasmaCyUtils.getComponent)('CellIcon');
var CellListItem = /*#__PURE__*/(0, _plasmaCyUtils.getComponent)('CellListItem');
var CellDisclosure = /*#__PURE__*/(0, _plasmaCyUtils.getComponent)('CellDisclosure');
var TextBox = /*#__PURE__*/(0, _plasmaCyUtils.getComponent)('TextBox');
var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';

var Icon = function Icon(_ref) {
  var size = _ref.size;
  return /*#__PURE__*/_react["default"].createElement(CellIcon, {
    size: size,
    as: "img",
    alt: "avocado",
    src: src
  });
};

var title = 'Hello World of Plasma';
var subTitle = 'Use with wisdom';
describe('plasma-ui: Cell', function () {
  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
  });
  it('simple', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Cell, {
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: title,
        subTitle: subTitle
      })
    })));
    cy.matchImageSnapshot();
  });
  it('__icon', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Cell, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: title,
        subTitle: subTitle
      })
    })));
    cy.matchImageSnapshot();
  });
  it('__icon_size', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, ['xs', 's', 'm', 'l', 'xl', 'xxl'].map(function (size) {
      return /*#__PURE__*/_react["default"].createElement(Cell, {
        key: size,
        contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, {
          size: size
        }),
        content: /*#__PURE__*/_react["default"].createElement(TextBox, {
          title: title,
          subTitle: subTitle
        })
      });
    })));
    cy.matchImageSnapshot();
  });
  it('__right', function () {
    var content = /*#__PURE__*/_react["default"].createElement(TextBox, {
      title: title,
      subTitle: subTitle
    });

    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Cell, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/_react["default"].createElement(Icon, null)
    }), /*#__PURE__*/_react["default"].createElement(Cell, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: "Details"
      })
    }), /*#__PURE__*/_react["default"].createElement(Cell, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: "Details",
        subTitle: "info"
      })
    }), /*#__PURE__*/_react["default"].createElement(Cell, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: "Details",
        subTitle: "info"
      }), /*#__PURE__*/_react["default"].createElement(Icon, {
        size: "s"
      }))
    })));
    cy.matchImageSnapshot();
  });
  it('_align_left', function () {
    var content = /*#__PURE__*/_react["default"].createElement(TextBox, {
      label: "indeed",
      caption: "\u0421\u043A\u0438\u0434\u043A\u0430 42%",
      title: title,
      subTitle: subTitle
    });

    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, ['top', 'center', 'bottom'].map(function (alignLeft) {
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(Cell, {
        key: alignLeft,
        alignLeft: alignLeft,
        contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
        content: content,
        contentRight: /*#__PURE__*/_react["default"].createElement(TextBox, {
          title: "Details",
          subTitle: "info"
        })
      }), /*#__PURE__*/_react["default"].createElement("hr", null));
    })));
    cy.matchImageSnapshot();
  });
  it('_align_right', function () {
    var content = /*#__PURE__*/_react["default"].createElement(TextBox, {
      label: "indeed",
      caption: "\u0421\u043A\u0438\u0434\u043A\u0430 42%",
      title: title,
      subTitle: subTitle
    });

    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, ['top', 'center'].map(function (alignRight) {
      return /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(Cell, {
        key: alignRight,
        alignRight: alignRight,
        contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
        content: content,
        contentRight: /*#__PURE__*/_react["default"].createElement(TextBox, {
          title: "Details",
          subTitle: "info"
        })
      }), /*#__PURE__*/_react["default"].createElement("hr", null));
    })));
    cy.matchImageSnapshot();
  });
  it('_list_item', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(CellListItem, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        label: "lonely",
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/_react["default"].createElement(CellDisclosure, null)
    })), /*#__PURE__*/_react["default"].createElement(CellListItem, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/_react["default"].createElement(CellDisclosure, null)
    }), /*#__PURE__*/_react["default"].createElement(CellListItem, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/_react["default"].createElement(CellDisclosure, null)
    }), /*#__PURE__*/_react["default"].createElement(CellListItem, {
      contentLeft: /*#__PURE__*/_react["default"].createElement(Icon, null),
      content: /*#__PURE__*/_react["default"].createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/_react["default"].createElement(CellDisclosure, null)
    })));
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=Cell.component-test.js.map