"use strict";

var _react = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("react"));

var _plasmaCyUtils = /*#__PURE__*/require("@sberdevices/plasma-cy-utils");

var _plasmaTokens = /*#__PURE__*/require("@sberdevices/plasma-tokens");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var accent = _plasmaTokens.colorValues.accent; // TODO: PLASMA-1086

describe('plasma-ui: Header: desktop', function () {
  var Container = (0, _plasmaCyUtils.getComponent)('Container');
  var Header = (0, _plasmaCyUtils.getComponent)('Header');
  var Button = (0, _plasmaCyUtils.getComponent)('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
    cy.viewport(1280, 200);
  });
  it('simple', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__title', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__sub-title', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__logo', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__content', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_minimize', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_back', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      back: true,
      onBackClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_gradient', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      gradientColor: accent,
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
describe('plasma-ui: Header: mobile', function () {
  var Container = (0, _plasmaCyUtils.getComponent)('Container');
  var Header = (0, _plasmaCyUtils.getComponent)('Header');
  var Button = (0, _plasmaCyUtils.getComponent)('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
    cy.viewport('iphone-6');
  });
  it('simple', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__title', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__sub-title', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__logo', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__content', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_minimize', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_back', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      back: true,
      onBackClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_gradient', function () {
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      gradientColor: accent,
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
describe('plasma-ui: Header: _size', function () {
  var Container = (0, _plasmaCyUtils.getComponent)('Container');
  var Header = (0, _plasmaCyUtils.getComponent)('Header');
  var Button = (0, _plasmaCyUtils.getComponent)('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  it('_sberBox', function () {
    cy.viewport(1920, 200);
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      size: "sberBox",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_sberPortal', function () {
    cy.viewport(1280, 200);
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      size: "sberPortal",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_mobile', function () {
    cy.viewport('iphone-6');
    (0, _plasmaCyUtils.mount)( /*#__PURE__*/_react["default"].createElement(_plasmaCyUtils.CypressTestDecorator, null, /*#__PURE__*/_react["default"].createElement(Container, null, /*#__PURE__*/_react["default"].createElement(Header, {
      size: "mobile",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/_react["default"].createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=Header.component-test.js.map