import React, { HTMLAttributes, MouseEventHandler } from 'react';
import { HeaderRootProps } from './HeaderRoot';
interface ArrowProps {
    /**
     * Тип кнопки-стрелки - "назад" или "свернуть".
     */
    arrow: 'back' | 'minimize';
    /**
     * Обработчик клика по кнопке-стрелке.
     */
    onArrowClick?: MouseEventHandler<HTMLButtonElement>;
}
interface LogoProps {
    /**
     * Путь до картинки с логотипом (src)
     */
    logo: string;
    /**
     * Alt логотипа
     */
    logoAlt?: string;
}
interface NoLogoProps {
    logo?: undefined;
    logoAlt?: never;
}
interface TitleProps {
    /**
     * Заголовок страницы.
     */
    title: string;
    /**
     * Подзаголовок страницы.
     */
    subTitle?: string;
}
interface NoTitleProps {
    title?: undefined;
    subTitle?: never;
}
export declare type NeuHeaderProps = HTMLAttributes<HTMLDivElement> & ArrowProps & (LogoProps | NoLogoProps) & (TitleProps | NoTitleProps) & Pick<HeaderRootProps, 'gradientColor'>;
/**
 * Сборный компонент для отрисовки шапки страницы.
 * Уже включает в себя все составные части шапки.
 * Компонент реализован для упрощения работы с шапкой при разработке проекта на Typescript.
 * Изменения в свойствах:
 * * Имеет упрощенный интерфейс - свойства `back` и `minimize` заменены на свойство `arrow`;
 * * Обработчики клика по стрелке `onBackClick` и `onMinimizeClick` заменены на обработчик `onArrowClick`;
 * * Свойство `subtitle` переименовано в `subTitle`.
 * `NeuHeader` заменит собой исходный `Header` в будущих версиях.
 */
export declare const NeuHeader: React.FC<NeuHeaderProps>;
export {};
//# sourceMappingURL=NeuHeader.d.ts.map