import type { FC, HTMLAttributes } from 'react';
import { DisabledProps } from '@sberdevices/plasma-core';
import { CarouselProps } from '../Carousel';
import type { PickerItem as PickerItemType, SizeProps, PickerVisibleItems } from './types';
export interface PickerProps extends SizeProps, DisabledProps, Omit<HTMLAttributes<HTMLDivElement>, 'onChange'>, Pick<CarouselProps, 'scrollSnapType'> {
    /**
     * Список опций
     */
    items: PickerItemType[];
    /**
     * Значение компонента
     */
    value: string | number | Date;
    /**
     * Отображать стрелки для переключения
     */
    controls?: boolean;
    /**
     * Отображаемое количество опций
     */
    visibleItems?: PickerVisibleItems;
    /**
     * Обработчик изменения значения
     */
    onChange?: (value: PickerItemType) => void;
    /**
     * Компонент в фокусе (визуально, независимо от tabIndex)
     */
    focused?: boolean;
    /**
     * Автофокус на компоненте.
     */
    autofocus?: boolean;
    /**
     * Добавляет нативный инпут для отправки в формах. Используется `input[type=hidden]`
     */
    enableNativeControl?: boolean;
    /**
     * Имя нативного инпута. Полезно при отправке uncontrolled-форм.
     * Используется вместе с пропом `enableNativeControl`.
     */
    name?: string;
    /**
     * Бесконечная прокрутка; выключена по умолчанию для lowPerformance Devices
     */
    infiniteScroll?: boolean;
}
/**
 * Компонент для отображения барабана-пикера,
 * позволяющего визуально проскроллить опции вверх-вниз.
 */
export declare const Picker: FC<PickerProps>;
//# sourceMappingURL=Picker.d.ts.map