import React from 'react';
import { mount, CypressTestDecorator, getComponent } from '@sberdevices/plasma-cy-utils';
var Cell = /*#__PURE__*/getComponent('Cell');
var CellIcon = /*#__PURE__*/getComponent('CellIcon');
var CellListItem = /*#__PURE__*/getComponent('CellListItem');
var CellDisclosure = /*#__PURE__*/getComponent('CellDisclosure');
var TextBox = /*#__PURE__*/getComponent('TextBox');
var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';

var Icon = function Icon(_ref) {
  var size = _ref.size;
  return /*#__PURE__*/React.createElement(CellIcon, {
    size: size,
    as: "img",
    alt: "avocado",
    src: src
  });
};

var title = 'Hello World of Plasma';
var subTitle = 'Use with wisdom';
describe('plasma-ui: Cell', function () {
  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
  });
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Cell, {
      content: /*#__PURE__*/React.createElement(TextBox, {
        title: title,
        subTitle: subTitle
      })
    })));
    cy.matchImageSnapshot();
  });
  it('__icon', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Cell, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: /*#__PURE__*/React.createElement(TextBox, {
        title: title,
        subTitle: subTitle
      })
    })));
    cy.matchImageSnapshot();
  });
  it('__icon_size', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, ['xs', 's', 'm', 'l', 'xl', 'xxl'].map(function (size) {
      return /*#__PURE__*/React.createElement(Cell, {
        key: size,
        contentLeft: /*#__PURE__*/React.createElement(Icon, {
          size: size
        }),
        content: /*#__PURE__*/React.createElement(TextBox, {
          title: title,
          subTitle: subTitle
        })
      });
    })));
    cy.matchImageSnapshot();
  });
  it('__right', function () {
    var content = /*#__PURE__*/React.createElement(TextBox, {
      title: title,
      subTitle: subTitle
    });
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Cell, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/React.createElement(Icon, null)
    }), /*#__PURE__*/React.createElement(Cell, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/React.createElement(TextBox, {
        title: "Details"
      })
    }), /*#__PURE__*/React.createElement(Cell, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/React.createElement(TextBox, {
        title: "Details",
        subTitle: "info"
      })
    }), /*#__PURE__*/React.createElement(Cell, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: content,
      contentRight: /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TextBox, {
        title: "Details",
        subTitle: "info"
      }), /*#__PURE__*/React.createElement(Icon, {
        size: "s"
      }))
    })));
    cy.matchImageSnapshot();
  });
  it('_align_left', function () {
    var content = /*#__PURE__*/React.createElement(TextBox, {
      label: "indeed",
      caption: "\u0421\u043A\u0438\u0434\u043A\u0430 42%",
      title: title,
      subTitle: subTitle
    });
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, ['top', 'center', 'bottom'].map(function (alignLeft) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Cell, {
        key: alignLeft,
        alignLeft: alignLeft,
        contentLeft: /*#__PURE__*/React.createElement(Icon, null),
        content: content,
        contentRight: /*#__PURE__*/React.createElement(TextBox, {
          title: "Details",
          subTitle: "info"
        })
      }), /*#__PURE__*/React.createElement("hr", null));
    })));
    cy.matchImageSnapshot();
  });
  it('_align_right', function () {
    var content = /*#__PURE__*/React.createElement(TextBox, {
      label: "indeed",
      caption: "\u0421\u043A\u0438\u0434\u043A\u0430 42%",
      title: title,
      subTitle: subTitle
    });
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, ['top', 'center'].map(function (alignRight) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Cell, {
        key: alignRight,
        alignRight: alignRight,
        contentLeft: /*#__PURE__*/React.createElement(Icon, null),
        content: content,
        contentRight: /*#__PURE__*/React.createElement(TextBox, {
          title: "Details",
          subTitle: "info"
        })
      }), /*#__PURE__*/React.createElement("hr", null));
    })));
    cy.matchImageSnapshot();
  });
  it('_list_item', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(CellListItem, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: /*#__PURE__*/React.createElement(TextBox, {
        label: "lonely",
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/React.createElement(CellDisclosure, null)
    })), /*#__PURE__*/React.createElement(CellListItem, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: /*#__PURE__*/React.createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/React.createElement(CellDisclosure, null)
    }), /*#__PURE__*/React.createElement(CellListItem, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: /*#__PURE__*/React.createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/React.createElement(CellDisclosure, null)
    }), /*#__PURE__*/React.createElement(CellListItem, {
      contentLeft: /*#__PURE__*/React.createElement(Icon, null),
      content: /*#__PURE__*/React.createElement(TextBox, {
        title: title,
        subTitle: subTitle
      }),
      contentRight: /*#__PURE__*/React.createElement(CellDisclosure, null)
    })));
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=Cell.component-test.js.map