import React from 'react';
import { mount, CypressTestDecorator, getComponent } from '@sberdevices/plasma-cy-utils';
import { colorValues } from '@sberdevices/plasma-tokens';
var accent = colorValues.accent; // TODO: PLASMA-1086

describe('plasma-ui: NeuHeader: desktop', function () {
  var Container = getComponent('Container');
  var Header = getComponent('NeuHeader');
  var Button = getComponent('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
    cy.viewport(1280, 200);
  });
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__title', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__sub-title', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__logo', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__content', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subTitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_minimize', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_back', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      back: true,
      onBackClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_gradient', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      gradientColor: accent,
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
describe('plasma-ui: NeuHeader: mobile', function () {
  var Container = getComponent('Container');
  var Header = getComponent('NeuHeader');
  var Button = getComponent('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  beforeEach(function () {
    cy.intercept(src, function (req) {
      req.reply({
        fixture: 'images/avocado.png'
      });
    });
    cy.viewport('iphone-6');
  });
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__title', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      title: title
    }))));
    cy.matchImageSnapshot();
  });
  it('__sub-title', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__logo', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('__content', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      logo: src,
      logoAlt: "avocado",
      title: title,
      subTitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_minimize', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_back', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      back: true,
      onBackClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }))));
    cy.matchImageSnapshot();
  });
  it('_gradient', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      gradientColor: accent,
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subtitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
describe('plasma-ui: NeuHeader: _size', function () {
  var Container = getComponent('Container');
  var Header = getComponent('NeuHeader');
  var Button = getComponent('HeaderButton');
  var src = 'https://plasma.sberdevices.ru/ui-storybook/images/avocado.png';
  var title = 'Hello World of Plasma';
  var subTitle = 'Use with wisdom';

  var noop = function noop() {};

  it('_sberBox', function () {
    cy.viewport(1920, 200);
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      size: "sberBox",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_sberPortal', function () {
    cy.viewport(1280, 200);
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      size: "sberPortal",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
  it('_mobile', function () {
    cy.viewport('iphone-6');
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Header, {
      size: "mobile",
      minimize: true,
      onMinimizeClick: noop,
      logo: src,
      title: title,
      subTitle: subTitle
    }, /*#__PURE__*/React.createElement(Button, {
      text: "buy"
    })))));
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=NeuHeader.component-test.js.map