/* eslint-disable cypress/no-unnecessary-waiting */
import React from 'react';
import { mount, CypressTestDecorator, getComponent } from '@sberdevices/plasma-cy-utils';

var noop = function noop() {};

describe('plasma-ui: DatePicker', function () {
  var DatePicker = getComponent('DatePicker');

  var AutofocusedDatePicker = function AutofocusedDatePicker() {
    return /*#__PURE__*/React.createElement(DatePicker, {
      scrollSnapType: "none",
      onChange: noop,
      infiniteScroll: false,
      value: new Date(2022, 0, 12),
      min: new Date(2000, 3, 15),
      max: new Date(2025, 10, 30),
      autofocus: true
    });
  };

  it('default', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(DatePicker, {
      value: new Date(1985, 8, 1),
      min: new Date(1975, 1, 1),
      max: new Date(1985, 10, 30)
    })));
    cy.matchImageSnapshot();
  });
  it('without infiniteScroll', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(DatePicker, {
      infiniteScroll: false,
      value: new Date(1980, 8, 1),
      min: new Date(1975, 1, 1),
      max: new Date(1985, 10, 30)
    })));
    cy.matchImageSnapshot();
  });
  it('change values', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(DatePicker, {
      scrollSnapType: "none",
      onChange: noop,
      value: new Date(1985, 8, 1),
      min: new Date(1975, 1, 1),
      max: new Date(1995, 10, 30)
    }))); // отключение анимаций на всех div'ах внутри окружения, TODO: перенести в plasma-cy-utils?

    cy.get('div').invoke('attr', 'style', 'transition: unset; animation: none; scroll-snap-type: none;');
    cy.get('div > div:nth-child(1)').contains('5').click({
      force: true
    });
    cy.wait(150);
    cy.get('div > div:nth-child(2)').contains('мая').click({
      force: true
    });
    cy.wait(150);
    cy.get('div > div:nth-child(3)').contains('1979').click({
      force: true
    });
    cy.wait(1000);
    cy.matchImageSnapshot();
  });
  it('with controls', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(DatePicker, {
      value: new Date(1980, 8, 1),
      min: new Date(1975, 1, 1),
      max: new Date(1985, 10, 30),
      controls: true,
      autofocus: true
    })));
    cy.matchImageSnapshot();
  });
  it('jump 10 down', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(AutofocusedDatePicker, null)));
    cy.get('body').type('{pagedown}');
    cy.wait(100);
    cy.matchImageSnapshot();
  });
  it('jump 10 up', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(AutofocusedDatePicker, null)));
    cy.get('body').type('{pageup}');
    cy.wait(100);
    cy.matchImageSnapshot();
  });
  it('jump home', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(AutofocusedDatePicker, null)));
    cy.get('body').type('{home}');
    cy.wait(100);
    cy.matchImageSnapshot();
  });
  it('jump end', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(AutofocusedDatePicker, null)));
    cy.get('body').type('{end}');
    cy.wait(100);
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=DatePicker.component-test.js.map