import React from 'react';
import { mount, CypressTestDecorator, getComponent } from '@sberdevices/plasma-cy-utils';
describe('plasma-core: Radiobox', function () {
  var Radiobox = getComponent('Radiobox');
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, null)));
    cy.matchImageSnapshot();
  });
  it('with focus', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      label: "checkbox with focus"
    })));
    cy.get('input').focus();
    cy.matchImageSnapshot();
  });
  it('__label', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      label: "simple radiobox"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      label: /*#__PURE__*/React.createElement("span", null, "radiobox with ", /*#__PURE__*/React.createElement("a", {
        href: "https://plasma.sberdevices.ru/"
      }, "link"))
    })));
    cy.matchImageSnapshot();
  });
  it('__description', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      label: "simple radiobox",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      label: "simple radiobox",
      description: /*#__PURE__*/React.createElement("span", null, "\u041E\u0431 ", /*#__PURE__*/React.createElement("a", {
        href: "https://plasma.sberdevices.ru"
      }, "\u044D\u043B\u0435\u043A\u0442\u0440\u043E\u043E\u0432\u0446\u0430\u0445"))
    })));
    cy.matchImageSnapshot();
  });
  it('_checked', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      checked: true,
      label: "radiobox checked",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      label: "radiobox",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    })));
    cy.matchImageSnapshot();
  });
  it('_focused', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      focused: true,
      label: "radiobox checked",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      name: "robots",
      focused: true,
      checked: true,
      label: "radiobox",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    })));
    cy.matchImageSnapshot();
  });
  it('_disabled', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Radiobox, {
      checked: true,
      disabled: true,
      label: "radiobox checked",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      disabled: true,
      label: "radiobox",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    })));
    cy.matchImageSnapshot();
  });
  it(':id', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, {
      noSSR: true
    }, /*#__PURE__*/React.createElement(Radiobox, {
      name: "uniqId",
      label: "radiobox",
      description: "\u041E \u0447\u0451\u043C \u043C\u0435\u0447\u0442\u0430\u044E\u0442 \u0440\u043E\u0431\u043E\u0442\u044B?"
    })));
    cy.get('[name="uniqId"]').should('have.attr', 'id');
  });
  it('squeezes', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement("div", {
      style: {
        overflow: 'hidden',
        width: 150
      }
    }, /*#__PURE__*/React.createElement(Radiobox, {
      checked: true,
      disabled: true,
      label: "Radiobox with a very very very very very long label",
      description: "Radiobox description with a very very very very very long text"
    }), /*#__PURE__*/React.createElement(Radiobox, {
      disabled: true,
      label: "Radiobox 2",
      description: "Radiobox 2 description"
    }))));
    cy.matchImageSnapshot();
  });
});
describe('plasma-core: RadioGroup', function () {
  var Radiobox = getComponent('Radiobox');
  var RadioGroup = getComponent('RadioGroup');
  var H3 = getComponent('Headline3');
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(RadioGroup, {
      "aria-labelledby": "radiogroup-title-id"
    }, /*#__PURE__*/React.createElement(H3, {
      id: "radiogroup-title-id"
    }, "\u0417\u0430\u0433\u043E\u043B\u043E\u0432\u043E\u043A"), /*#__PURE__*/React.createElement(Radiobox, {
      name: "radio-1",
      label: "\u0420\u0430\u0434\u0438\u043E\u043A\u043D\u043E\u043F\u043A\u0430 1",
      description: "\u041E\u043F\u0438\u0441\u0430\u043D\u0438\u0435 1",
      defaultChecked: true
    }), /*#__PURE__*/React.createElement(Radiobox, {
      name: "radio-1",
      label: "\u0420\u0430\u0434\u0438\u043E\u043A\u043D\u043E\u043F\u043A\u0430 2",
      description: "\u041E\u043F\u0438\u0441\u0430\u043D\u0438\u0435 2"
    }))));
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=RadioboxBase.component-test.js.map