import React from 'react';
export var useSheetSwipe = function useSheetSwipe(args) {
  var contentWrapperRef = args.contentWrapperRef,
      handleRef = args.handleRef,
      onClose = args.onClose;
  React.useEffect(function () {
    if (!handleRef.current || !contentWrapperRef.current) {
      return;
    }

    var handleEl = handleRef.current;
    var contentWrapperEl = contentWrapperRef.current;
    var curtainHeight = contentWrapperEl.offsetHeight;
    var startY;
    var currentY;

    var onTouchStart = function onTouchStart(event) {
      startY = event.changedTouches[0].clientY;
      currentY = startY;
      contentWrapperEl.style.transition = 'none';
    };

    var onTouchMove = function onTouchMove(event) {
      var clientY = event.changedTouches[0].clientY;
      currentY = Math.max(startY, clientY);
      contentWrapperEl.style.transform = "translateY(".concat(currentY - startY, "px)");
    };

    var onTouchEnd = function onTouchEnd(event) {
      var endY = event.changedTouches[0].clientY;
      var offsetY = endY - startY;
      contentWrapperEl.style.transform = '';
      contentWrapperEl.style.transition = '';

      if (offsetY / curtainHeight > 0.2) {
        onClose();
      }
    };

    handleEl.addEventListener('touchstart', onTouchStart);
    handleEl.addEventListener('touchmove', onTouchMove);
    handleEl.addEventListener('touchend', onTouchEnd);
    return function () {
      handleEl.removeEventListener('touchstart', onTouchStart);
      handleEl.removeEventListener('touchmove', onTouchMove);
      handleEl.removeEventListener('touchend', onTouchEnd);
    };
  }, []);
};
//# sourceMappingURL=useSheetSwipe.js.map