import React from 'react';
import { mount, CypressTestDecorator, getComponent, PadMe, SpaceMe, withNoAnimation } from '@sberdevices/plasma-cy-utils';
import { typography } from '@sberdevices/plasma-tokens';
import { radiuses } from '../..';
var textSizes = /*#__PURE__*/Object.keys(typography);
var roundnessKeys = /*#__PURE__*/Object.keys(radiuses).map(function (r) {
  return Number(r);
});
describe('plasma-core: Skeleton', function () {
  describe('LineSkeleton', function () {
    var LineSkeleton = getComponent('LineSkeleton');
    var Line = withNoAnimation(LineSkeleton);
    it('simple', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Line, null)));
      cy.matchImageSnapshot();
    });
    it('_size', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, textSizes.map(function (size) {
        return /*#__PURE__*/React.createElement(Line, {
          key: size,
          size: size
        });
      })));
      cy.matchImageSnapshot();
    });
    it('_roundness', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, roundnessKeys.map(function (roundness) {
        return /*#__PURE__*/React.createElement(Line, {
          key: roundness,
          roundness: roundness
        });
      })));
      cy.matchImageSnapshot();
    });
  });
  describe('RectSkeleton', function () {
    var RectSkeleton = getComponent('RectSkeleton');
    var Rect = withNoAnimation(RectSkeleton);
    it('simple', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Rect, {
        width: "12rem",
        height: "8rem"
      })));
      cy.matchImageSnapshot();
    });
    it('_size', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Rect, {
        width: "12rem",
        height: "8rem"
      }), /*#__PURE__*/React.createElement(SpaceMe, null), /*#__PURE__*/React.createElement(Rect, {
        width: 128,
        height: 128
      }), /*#__PURE__*/React.createElement(SpaceMe, null), /*#__PURE__*/React.createElement(Rect, {
        height: "8rem"
      })));
      cy.matchImageSnapshot();
    });
    it('_roundness', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, roundnessKeys.map(function (roundness) {
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Rect, {
          key: roundness,
          width: "12rem",
          height: "2rem",
          roundness: roundness
        }), /*#__PURE__*/React.createElement(PadMe, {
          key: roundness
        }));
      })));
      cy.matchImageSnapshot();
    });
  });
  describe('TextSkeleton', function () {
    var TextSkeleton = getComponent('TextSkeleton');
    var Text = withNoAnimation(TextSkeleton);
    it('simple', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Text, null)));
      cy.matchImageSnapshot();
    });
    it('__lines', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Text, {
        lines: 0
      }), /*#__PURE__*/React.createElement(Text, {
        lines: 1
      }), /*#__PURE__*/React.createElement(Text, {
        lines: 2
      }), /*#__PURE__*/React.createElement(Text, {
        lines: 3
      }), /*#__PURE__*/React.createElement(Text, {
        lines: 4
      })));
      cy.matchImageSnapshot();
    });
    it('__lines:20', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Text, {
        lines: 20
      })));
      cy.matchImageSnapshot();
    });
    it('_size', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, textSizes.map(function (size) {
        return /*#__PURE__*/React.createElement(Text, {
          key: size,
          size: size
        });
      })));
      cy.matchImageSnapshot();
    });
    it('_roundness', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, roundnessKeys.map(function (roundness) {
        return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Text, {
          key: roundness,
          roundness: roundness
        }), /*#__PURE__*/React.createElement(PadMe, {
          key: roundness
        }));
      })));
      cy.matchImageSnapshot();
    });
    it(':width', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Text, {
        lines: 3,
        width: 50
      }), /*#__PURE__*/React.createElement(Text, {
        lines: 3,
        width: "2rem"
      })));
      cy.matchImageSnapshot();
    });
  });
  describe('withSkeleton', function () {
    var withSkeleton = getComponent('withSkeleton');
    var Button = getComponent('Button');
    var Btn = withNoAnimation(withSkeleton(Button));
    it('simple', function () {
      mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Btn, {
        view: "primary",
        text: "Loading",
        skeleton: true
      }), /*#__PURE__*/React.createElement(PadMe, null), /*#__PURE__*/React.createElement(Btn, {
        view: "primary",
        text: "Done"
      })));
      cy.matchImageSnapshot();
    });
  });
});
//# sourceMappingURL=SkeletonBase.component-test.js.map