import React from 'react';
import { mount, CypressTestDecorator, getComponent, PadMe } from '@sberdevices/plasma-cy-utils';

var noop = function noop() {};

var dragAndDrop = function dragAndDrop(chainableSelector, coord) {
  chainableSelector.trigger('mousedown').trigger('mousemove', coord).trigger('mouseup');
};

describe('plasma-ui: Slider', function () {
  var Slider = getComponent('Slider');
  it('simple', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      value: 42,
      min: 0,
      max: 100
    })));
    cy.matchImageSnapshot();
  });
  it('_disabled', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      disabled: true,
      value: 42,
      min: 0,
      max: 100
    })));
    cy.matchImageSnapshot();
  });
  it('double', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      value: [13, 42],
      min: 0,
      max: 100
    })));
    cy.matchImageSnapshot();
  });
  it('drag and drop with single', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      onChange: noop,
      onChangeCommitted: noop,
      value: 50,
      min: 0,
      max: 100
    })));
    dragAndDrop(cy.root(), {
      clientX: 350,
      clientY: 15
    });
    cy.matchImageSnapshot();
  });
  it('drag and drop without onChange', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      onChangeCommitted: noop,
      value: [0, 50],
      min: 0,
      max: 100
    }), /*#__PURE__*/React.createElement(PadMe, null), /*#__PURE__*/React.createElement(Slider, {
      onChangeCommitted: noop,
      value: 50,
      min: 0,
      max: 100
    })));
    dragAndDrop(cy.root().get('div > div + div').first(), {
      clientX: 50,
      clientY: 15
    });
    dragAndDrop(cy.root().get('div > div + div').last(), {
      clientX: 350,
      clientY: 55
    });
    cy.matchImageSnapshot();
  });
  it('drag and drop with double', function () {
    mount( /*#__PURE__*/React.createElement(CypressTestDecorator, null, /*#__PURE__*/React.createElement(Slider, {
      onChange: noop,
      onChangeCommitted: noop,
      value: [25, 75],
      min: 0,
      max: 100
    })));
    dragAndDrop(cy.root().get('div > div + div').first(), {
      clientX: 50,
      clientY: 15
    });
    dragAndDrop(cy.root().get('div > div + div').last(), {
      clientX: 450,
      clientY: 15
    });
    cy.matchImageSnapshot();
  });
});
//# sourceMappingURL=Slider.component-test.js.map