"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useRemoteListener = void 0;

var _react = /*#__PURE__*/require("react");

var navKeys = ['ArrowUp', 'ArrowDown', 'ArrowLeft', 'ArrowRight', 'Enter', 'PageUp', 'PageDown', 'Home', 'End'];

var getRemoteKey = function getRemoteKey(key, isLong) {
  switch (key) {
    case 'ArrowUp':
      return isLong ? 'LONG_UP' : 'UP';

    case 'ArrowDown':
      return isLong ? 'LONG_DOWN' : 'DOWN';

    case 'ArrowLeft':
      return isLong ? 'LONG_LEFT' : 'LEFT';

    case 'ArrowRight':
      return isLong ? 'LONG_RIGHT' : 'RIGHT';

    case 'Enter':
      return isLong ? 'LONG_OK' : 'OK';

    case 'PageUp':
      return 'PAGE_UP';

    case 'PageDown':
      return 'PAGE_DOWN';

    case 'Home':
      return 'HOME';

    case 'End':
      return 'END';

    default:
      return undefined;
  }
};
/**
 * Создает слушателя событий клавиатуры,
 * который вызывает коллбек при нажатии кнопок навигации.
 * @param {Function} cb
 * @param {number} keypressTimeMs
 * @return {void}
 */


var useRemoteListener = function useRemoteListener(cb) {
  var keypressTimeMs = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 150;
  var keydown = (0, _react.useRef)(null);
  (0, _react.useEffect)(function () {
    var handleKeydown = function handleKeydown(event) {
      var isLong = Boolean(keydown.current && Date.now() - keydown.current < keypressTimeMs);
      var remoteKey = getRemoteKey(event.key, isLong);

      if (!remoteKey) {
        return;
      }

      cb(remoteKey, event);
      keydown.current = Date.now();
    };

    var handleKeyup = function handleKeyup(event) {
      if (navKeys.indexOf(event.key) === -1) {
        return;
      }

      keydown.current = null;
    };

    window.addEventListener('keydown', handleKeydown);
    window.addEventListener('keyup', handleKeyup);
    return function () {
      window.removeEventListener('keydown', handleKeydown);
      window.removeEventListener('keyup', handleKeyup);
    };
  }, [cb]);
};

exports.useRemoteListener = useRemoteListener;
//# sourceMappingURL=useRemoteListener.js.map